@@ -10,8 +10,8 @@ G_BEGIN_DECLS
 
 /* Enumerations from "lunar-date.h" */
 
-#define LUNAR_TYPE_UNAR_DATE_ERROR	(l_unar_date_error_get_type())
-GType l_unar_date_error_get_type	(void) G_GNUC_CONST;
+#define LUNAR_TYPE_DATE_ERROR	(lunar_date_error_get_type())
+GType lunar_date_error_get_type	(void) G_GNUC_CONST;
 
 /* Enumerations from "lunar-calendar.h" */
 
